@@ -2,7 +2,7 @@ package POE::Component::IRC::Plugin::BotAddressed;
 BEGIN {
   $POE::Component::IRC::Plugin::BotAddressed::AUTHORITY = 'cpan:HINRIK';
 }
-$POE::Component::IRC::Plugin::BotAddressed::VERSION = '6.87';
+$POE::Component::IRC::Plugin::BotAddressed::VERSION = '6.88';
 use strict;
 use warnings FATAL => 'all';
 use Carp;
@@ -54,7 +54,7 @@ sub S_public {
     my $channels = ${ $_[1] };
     my $what = ${ $_[2] };
     my $me = $irc->nick_name();
-    my ($cmd) = $what =~ m/^\s*\Q$me\E[:,;.!?~]?\s*(.*)$/i;
+    my ($cmd) = $what =~ m/^\s*[@%]?\Q$me\E[:,;.!?~]?\s*(.*)$/i;
 
     return PCI_EAT_NONE if !defined $cmd && $what !~ /$me/i;
 
